@@ -1,6 +1,7 @@
 import sys
 
-help_doc_str = """usage: hello-x3m <command> [options]
+help_doc_str = """\
+usage: hello-x3m <command> [options]
 
 Commands:
     preprocess
@@ -20,10 +21,10 @@ def main(args=None):
     args = ["--help"] if len(args) == 0 else args
 
     if command == "preprocess":
-        from hello.x3m.preprocess import main as _main
+        from .preprocess import main as _main
         _main(args)
     elif command == "config":
-        from hello.x3m.config import main as _main
+        from .config import main as _main
         _main(args)
     else:
         print(help_doc_str)
